@@ -113,17 +113,16 @@ layout = [
 
 
 def mapUMC_CommandPattern(udm_value, encoding=()):
+    # type: (list[list[str]], univention.admin.handlers._Encoding) -> list[bytes]
     return [u':'.join(x).encode(*encoding) for x in udm_value]
 
 
 def unmapUMC_CommandPattern(ldap_value, encoding=()):
-    unmapped = []
-    for item in [x.decode(*encoding) for x in ldap_value]:
-        if u':' in item:
-            unmapped.append(item.split(u':', 1))
-        else:
-            unmapped.append((item, u''))
-    return unmapped
+    # type: (list[bytes], univention.admin.handlers._Encoding) -> list[tuple[str, str]]
+    return [
+        val.decode(*encoding).partition(u":")[::2]
+        for val in ldap_value
+    ]
 
 
 mapping = udm_mapping.mapping()
